#include "checkablecomboboxmodel.h"
#include <QStandardItem>


#include <QtDebug>

CheckableComboBoxModel::CheckableComboBoxModel(QObject *parent) : QStandardItemModel(parent) {
    connect(this, SIGNAL(itemChanged(QStandardItem *)), this, SLOT(onItemChanged(QStandardItem *)));
    QStandardItem* item = new QStandardItem("-");
    setItem(0, 0, item);
}

QStandardItem* CheckableComboBoxModel::addItem(const QString &i, bool checkable)
{
    setRowCount(rowCount() + 1);
    QStandardItem* item = new QStandardItem(i);
    if(checkable) {
        item->setFlags(Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
        item->setData(Qt::Checked, Qt::CheckStateRole);
    }
    setItem(rowCount() -1, 0, item);
    return item;
}

QStandardItem *CheckableComboBoxModel::findItem(const double &d) const
{
    for(int i = 0; i < rowCount(); i++)
        if(item(i)->text().toDouble() == d)
            return item(i);
    return nullptr;
}

void CheckableComboBoxModel::onItemChanged(QStandardItem *it)
{
    if(it->flags() & Qt::ItemIsUserCheckable) {
        qDebug() << __PRETTY_FUNCTION__ << it;
        emit itemChecked(it->text(), it->data(Qt::CheckStateRole).toBool());
    }
}
